@@ -76,6 +76,14 @@ def attach_profile_lua_scripts(redis_client,
                 expire_postfix=PROFILE_VALUE_EXPIRE_AT_POSTFIX
             ))
 
+    if not hasattr(redis_client, 'switch_profiles'):
+
+        redis_client.switch_profiles = redis_client.register_script(
+            LuaScripts.switch_profiles(
+                user_ttl=user_ttl,
+                user_ttl_margin=user_data_ttl_margin
+            ))
+
     if not hasattr(redis_client, 'finalize_profile'):
 
         redis_client.finalize_profile = redis_client.register_script(
